using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;


namespace IndiaStudyChannel.Colleges
{
	/// <summary>
	/// Summary description for AddCourseToCollege.
	/// </summary>
	public partial class AddCourseToCollege : System.Web.UI.Page
	{
	
		protected void Page_Load(object sender, System.EventArgs e)
		{
			// Put user code to initialize the page here
			if ( Page.IsPostBack )
				return;

			// Make sure user has logged in before can post a course.

			if ( Session["CurrentUser"] == null )
			{
				// User has not logged in. Redirect to login page and pass current URL as a query string
				// so that after login, we can redirect user to this page again.
				Response.Redirect("../Members/Login.aspx?ReturnUrl=" + Request.Url.PathAndQuery);
			}

			// Load the list of courses in the drop down.
			LoadCoursesDropdown();

			// Load the course types in the drop down
			LoadCourseTypesDropdown();

			string id = Request.QueryString["Id"];
			if ( id == null )
			{
				// No course id is passed in query string. So we are here to add a new course.
			}
			else
			{
				// Course Id is passed as query string. So we are here to edit a course.

				// Pre populate the course by the id.
				LoadCollegeCourseDetails( int.Parse(id) );
			}	
		}

		/// <summary>
		/// This method reads the details of the selected course and displays in the UI.
		/// </summary>
		/// <param name="courseId"></param>
		private void LoadCollegeCourseDetails( int id )
		{
			// Write the query to find the exact record from the database matching the given Id.
			string query = "Select * from CollegeCourses where Id = " + id;
			DataTable table = Utils.DataManager.ExecuteQuery(query);

			if ( table.Rows.Count > 0 )
			{
				DataRow dr = table.Rows[0];	// take the first row since we can assume that there will be only one row matching the id.

				// Only the administrator or the person who originally submitted this course can edit this. Make sure 
				// nobody else is trying to edit this.
				if ( !Utils.Utils.IsOwner(dr["PostedUser"]) )
				{
					lblMessage.Text = "Sorry, you are not the owner of this submission and you are not allowed to edit this. Please <a href='../Members/Login.aspx?ReturnUrl=" + Request.Url.PathAndQuery + "'>Sign In</a> using an Id with appropriate permissions.";
					btnSave.Enabled = false;
					return;
				}

				txtFeesStructure.Text = dr["FeesStructure"].ToString();
				txtSeatCount.Text = dr["Seats"].ToString();
				txtRemarks.Text = dr["Remarks"].ToString();

				// Initialize the drop down to the saved course.
				ddlCourseName.Items.FindByValue( dr["CourseId"].ToString() ).Selected = true;

				ddlCourseTypes.Items.FindByValue( dr["CourseTypeId"].ToString() ).Selected = true;
			}				
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    

		}
		#endregion

		protected void btnSave_Click(object sender, System.EventArgs e)
		{
			int courseId = Int32.Parse(ddlCourseName.SelectedValue.ToString());
			int courseTypeId = Int32.Parse(ddlCourseTypes.SelectedValue.ToString());

			string fees = txtFeesStructure.Text.Replace("'","''");
			string seats = txtSeatCount.Text.Replace("'","''");
			string remarks = txtRemarks.Text.Replace("'","''");
			
			int collegeId = int.Parse(Request.QueryString["CollegeId"].ToString());
			
			string query = "";

			string id = Request.QueryString["Id"];
			if ( id == null )
			{
				// There is no query string passed. We are adding a new one..
				query = "insert into CollegeCourses (CollegeId, CourseId, CourseTypeId, FeesStructure, Seats, Remarks, PostedUser) values(" + collegeId + ", " + courseId.ToString() + ", " + courseTypeId + ", '" + fees + "', '" + seats + "', '" + remarks + "', '" + Session["CurrentUser"].ToString() + "')";				
			}
			else
			{
				// collegeId is passed as query string... this means we are editing an existing one.
				query = "Update CollegeCourses set CourseId = '" + courseId + "', CourseTypeId = " + courseTypeId + ", FeesStructure = '" + fees + "', Seats = '" + seats + "', Remarks = '" + remarks + "' where Id = " + id;
			}

			Utils.DataManager.ExecuteNonQuery(query);

			Response.Redirect("CollegeDetails.aspx?CollegeId=" + collegeId);
		}

		/// <summary>
		/// This method loads the list of all courses in the dropdown.
		/// </summary>
		private void LoadCoursesDropdown()
		{
			string query = "Select Id, (CourseName + ' (' + majorSubject + ')') as CourseName from Courses";
			DataTable table = Utils.DataManager.ExecuteQuery(query);
				
			ddlCourseName.DataTextField = "CourseName";
			ddlCourseName.DataValueField = "Id";
			ddlCourseName.DataSource = table;            
			ddlCourseName.DataBind();
		}
		
		private void LoadCourseTypesDropdown()
		{
			string query = "Select Id, CourseType from CourseTypes order by CourseType ASC";
			DataTable table = Utils.DataManager.ExecuteQuery(query);

			ddlCourseTypes.DataTextField = "CourseType";
			ddlCourseTypes.DataValueField = "Id";
			ddlCourseTypes.DataSource = table;            
			ddlCourseTypes.DataBind();
		}

		protected void btnCancel_Click(object sender, System.EventArgs e)
		{
			int collegeId = int.Parse(Request.QueryString["CollegeId"].ToString());
			Response.Redirect("CollegeDetails.aspx?Id=" + collegeId);		
		}
	}
}
