using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;


namespace IndiaStudyChannel.Colleges
{
	/// <summary>
	/// Summary description for AddStudentToCollege.
	/// </summary>
	public partial class AddStudentToCollege : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox txtFeesStructure;
		protected System.Web.UI.WebControls.TextBox txtSeatCount;
		protected System.Web.UI.WebControls.DropDownList ddlStudentTypes;
	
		protected void Page_Load(object sender, System.EventArgs e)
		{
            this.Page.Form.DefaultFocus = ddlCourseName.ClientID;

			// Put user code to initialize the page here
			if ( Page.IsPostBack )
				return;

			// Make sure user has logged in before can post a student.

			if ( Session["CurrentUser"] == null )
			{
				// User has not logged in. Redirect to login page and pass current URL as a query string
				// so that after login, we can redirect user back to this page again.
				Response.Redirect("../Members/Login.aspx?ReturnUrl=" + Request.Url.PathAndQuery);
			}

			// Load the list of students in the drop down.
			LoadCoursesDropdown();

			LoadYearsDropdown();

			string id = Request.QueryString["Id"];
			if ( id == null )
			{
				// No student id is passed in query string. So we are here to add a new student.
			}
			else
			{
				// Id is passed as query string. So we are here to edit a student.
				// Pre populate the student details by the id.
				LoadClassmatesDetails( int.Parse(id) );
			}	
		}

		
		protected void btnSave_Click(object sender, System.EventArgs e)
		{
			int collegeId = int.Parse(Request.QueryString["CollegeId"].ToString());

			int courseId = Int32.Parse(ddlCourseName.SelectedValue.ToString());
			int year = Int32.Parse(ddlYears.SelectedValue.ToString());
			string remarks = txtRemarks.Text.Replace("'","''");			

			string query = "";

			string id = Request.QueryString["Id"];
			if ( id == null )
			{
				// There is no query string passed. We are adding a new one..
				query = "insert into Classmates (CollegeId, CourseId, yearCompleted, Remarks, UserId) values(" + collegeId + ", " + courseId + ", " + year + ", '" + remarks + "', '" + Session["CurrentUser"].ToString() + "')";				
			}
			else
			{
				// collegeId is passed as query string... this means we are editing an existing one.
				query = "Update Classmates set CollegeId = '" + collegeId + "', CourseId = " + courseId + ", YearCompleted = '" + year + "', Remarks = '" + remarks + "' where Id = " + id;
			}

			Utils.DataManager.ExecuteNonQuery(query);

			// Pass the tab "classmates" also to the collegedetails page so that it can display
			// the Classmates tab by default.
			Response.Redirect("CollegeDetails.aspx?CollegeId=" + collegeId + "&tab=classmates");
		}

		protected void btnCancel_Click(object sender, System.EventArgs e)
		{
			int collegeId = int.Parse(Request.QueryString["CollegeId"].ToString());

			// Pass the tab "classmates" also to the collegedetails page so that it can display
			// the Classmates tab by default.
			Response.Redirect("CollegeDetails.aspx?CollegeId=" + collegeId + "&tab=classmates");		
		}

		/// <summary>
		/// This method reads the details of the selected item and prepopulate the Ui for editing.
		/// </summary>
		/// <param name="id"></param>
		private void LoadClassmatesDetails( int id )
		{
			// Write the query to find the exact record from the database matching the given Id.
			string query = "Select Classmates.*, Colleges.CollegeName as CollegeName from Classmates, Colleges where Classmates.Id = " + id + " AND Colleges.Id = Classmates.CollegeId";

			DataTable table = Utils.DataManager.ExecuteQuery(query);
			DataRow row = table.Rows[0];

			// Only the administrator or the person who originally submitted this entry can edit this. Make sure 
			// nobody else is trying to edit this.
			if ( !Utils.Utils.IsOwner(row["UserId"]) )
			{
				lblMessage.Text = "Sorry, you are not the owner of this submission and you are not allowed to edit this. Please <a href='../Members/Login.aspx?ReturnUrl=" + Request.Url.PathAndQuery + "'>Sign In</a> using an Id with appropriate permissions.";
				btnSave.Enabled = false;
				return;
			}

			lblCollegeName.Text = "<h2>" + row["CollegeName"] + "</h2>";
			txtRemarks.Text = row["Remarks"].ToString();

			// Initialize the drop downs to the saved course.
			ddlCourseName.Items.FindByValue( row["CourseId"].ToString() ).Selected = true;

			ddlYears.SelectedIndex = -1;	// Remove all selections
			ddlYears.Items.FindByValue( row["YearCompleted"].ToString() ).Selected = true;
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    

		}
		#endregion

		/// <summary>
		/// This method loads the list of all courses for the selected college.
		/// </summary>
		private void LoadCoursesDropdown()
		{
			int collegeId = int.Parse(Request.QueryString["CollegeId"]);
			string query = "Select Courses.Id, (CourseName + ' (' + majorSubject + ')') as CourseName from Courses, CollegeCourses where Courses.Id = CollegeCourses.CourseId AND CollegeCourses.CollegeId = " + collegeId;
			DataTable table = Utils.DataManager.ExecuteQuery(query);
				
			ddlCourseName.DataTextField = "CourseName";
			ddlCourseName.DataValueField = "Id";
			ddlCourseName.DataSource = table;            
			ddlCourseName.DataBind();
		}
		

		/// <summary>
		/// This method loads the list of years
		/// </summary>
		private void LoadYearsDropdown()
		{
			// Populate the years starting from 1925 to (current year + 5)
			for (int year = (DateTime.Now.Year + 5); year > 1925; year--)
			{
				ddlYears.Items.Add(year.ToString());
			}

			// Select current year by default.
			ddlYears.Items.FindByValue( DateTime.Now.Year.ToString() ).Selected = true;
		}
	}
}
