using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;


namespace IndiaStudyChannel.Colleges
{
	/// <summary>
	/// Summary description for CollegeDetails.
	/// </summary>
	public partial class CollegeDetails : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.DataGrid dgPhotos;
        protected string collegeName = "";
        protected string collegeCity = "";
	
		protected void Page_Load(object sender, System.EventArgs e)
		{	
			int id = int.Parse(Request.QueryString["CollegeId"]);
			
			ShowCollegeDetails(id);

			string tab = Request.QueryString["Tab"];
			if ( tab == null || tab == "courses" )
			{
				// We are in the courses tab.. show all courses of this college.
				pnlCourses.Visible = true;

				if ( ! Page.IsPostBack )
					LoadCourses(id);
			}
			else if ( tab == "classmates" )
			{
				// We are in the classmates tab.
				pnlClassmates.Visible = true;
                
                // Set the default button so that when user press ENTER in this page, it will trigger the search for classmates!
                Page.Form.DefaultButton = btnSearchClassmates.UniqueID;

				if ( ! Page.IsPostBack )
				{
					LoadCoursesDropdown();
					LoadYearsDropdown();
					LoadClassmates(id);
				}
			}
			else if ( tab == "photos" )
			{
				// We are in the photos tab.
				pnlPhotos.Visible = true;
				LoadPhotos(id);

				string pageAction = Request.QueryString["PageAction"];
				if ( pageAction == "addphoto" )
				{
					// User has clicked the 'Add Photos' link. Show the panel to upload photos.
					pnlEditPhotos.Visible = true;
				}

				// If the current user is an administrator, then show the link to upload photo.
				if ( Utils.Utils.IsAdministrator() )
				{
					lblAddPhoto.Text = "<a href='CollegeDetails.aspx?CollegeId=" + Request.QueryString["CollegeId"].ToString() + "&tab=photos&pageaction=addphoto'>Add New Photo</a>";
				}
				else
				{
					lblAddPhoto.Text = "Only Administrator is allowed to submit new photos. If you have any new pictures for this institute/college, please <a href='../general/Contactus.aspx'>send to us</a>.";
				}
			}
		}

		#region College Details

		/// <summary>
		/// Edit College
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void lnkEdit_Click(object sender, System.EventArgs e)
		{
			int id = int.Parse(Request.QueryString["CollegeId"].ToString());

			Response.Redirect("AddCollege.aspx?CollegeId=" + id);
		}

		/// <summary>
		/// Delete College
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void lnkDelete_Click(object sender, System.EventArgs e)
		{
			if ( ! Utils.Utils.IsAdministrator() )
			{
				lblMessage.Text = "Sorry, only administrator has permission to delete this entry.";
				return;
			}

			int id = int.Parse(Request.QueryString["CollegeId"].ToString());
			DeleteCollege(id);

			Response.Redirect("Index.aspx");
		}

		/// <summary>
		/// This method displays the details of the specific college
		/// </summary>
		/// <param name="collegeId"></param>
		private void ShowCollegeDetails(int collegeId)
		{
			// Query to retrieve college details.
			string query = "Select Colleges.*, Universities.UniversityName from Colleges, Universities where Universities.id = Colleges.UniversityId AND Colleges.Id ='" + collegeId + "'";
			DataTable table = Utils.DataManager.ExecuteQuery(query);

			if ( table.Rows.Count > 0 )
			{
				DataRow dr = table.Rows[0];	// take the first row since we can assume that there will be only one row matching the id.

				// Only the administrator or the person who originally submitted this college can edit this. Make sure 
				// nobody else is trying to edit this.
				if ( Utils.Utils.IsOwner(dr["PostedUser"]) )
				{
					lnkEdit.Visible = true;
				}
				else
				{
					lnkEdit.Visible = false;
				}

				// Only administrator can delete a college.
				if ( Utils.Utils.IsAdministrator() )
				{
					lnkDelete.Visible = true;
				}
				else
				{
					lnkDelete.Visible = false;
				}

                collegeName = dr["CollegeName"].ToString();

                // Ensure the word 'university' is there in the title so that when any one 
                // search for this college name, search engines will show our page!
                if (collegeName.ToLower().IndexOf("college") == -1)
                    collegeName = collegeName + " College";

                collegeCity = dr["City"].ToString();

				lblName2.Text = dr["CollegeName"].ToString();
				lblCollegeName.Text = dr["CollegeName"].ToString();
				lblAddress.Text = dr["Address"].ToString();
				lblCity.Text = dr["City"].ToString();
				lblState.Text = dr["State"].ToString();
				lblPhoneNumber1.Text = dr["PhoneNumber1"].ToString();
				lblPhoneNumber2.Text = dr["PhoneNumber2"].ToString();
				lblEmail.Text = dr["Email"].ToString();
				lblHomePage.Text = dr["HomePage"].ToString();
				lblUniversity.Text = "<a href='../universities/UniversityDetails.aspx?Id=" + dr["UniversityId"].ToString() + "'>" + dr["UniversityName"].ToString() + "</a>";
				lblDescription.Text = dr["Description"].ToString();

                this.Master.Page.Title = collegeName + " " + dr["City"].ToString() + " phone number & email address";
			}
		}

		// This method is to delete a college based on it's Id.
		private void DeleteCollege(int id )
		{
			// Before we delete a college, we must delete all courses offered in this college.
			// Query to delete all college courses for this college
			string query = "delete from CollegeCourses Where CollegeId = " + id;
			Utils.DataManager.ExecuteNonQuery(query);

			query = "delete from Classmates Where CollegeId = " + id;
			Utils.DataManager.ExecuteNonQuery(query);

			query = "delete from Colleges Where Id = " + id;
			Utils.DataManager.ExecuteNonQuery(query);
		}

		#endregion
		
		#region Courses

		/// <summary>
		/// Load all courses running in this college.
		/// </summary>
		/// <param name="collegeId"></param>
		private void LoadCourses(int collegeId)
		{
			// Query to find the  courses offered in this college.
			string query = "Select CollegeCourses.Id, Courses.Id as CourseId, CourseName, MajorSubject, FeesStructure, Seats, Remarks from Courses, CollegeCourses where CollegeCourses.CollegeId = " + collegeId + " AND COurses.Id = CollegeCourses.COurseId";

			DataTable data = Utils.DataManager.ExecuteQuery(query);

			if ( data.Rows.Count == 0 )
			{
				lblMessage1.Text = "No courses available.";
			}
			else
			{
				dgCourses.DataSource = data;
				dgCourses.DataBind();
			}
		}
		
		/// <summary>
		/// This method is called from the data grid when the administrator clicks Edit or Delete link.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void dgCourses_RowCommand(object sender, DataGridCommandEventArgs e)
		{
			string argument = e.CommandArgument.ToString();

			if (e.CommandName == "Delete")
			{
				// Delete the row.
				string query = "delete from CollegeCourses Where Id = " + argument;

				Utils.DataManager.ExecuteNonQuery(query);

				LoadCourses(int.Parse(Request.QueryString["Id"].ToString()));
			}
			else if (e.CommandName == "Edit")
			{
				Response.Redirect("AddCourseToCollege.aspx?Id=" + argument + "&CollegeId=" + Request.QueryString["id"].ToString());
			}
		}

		/// <summary>
		/// This method is called from the courses data grid
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void dgCourses_DataBind(object sender, DataGridItemEventArgs e)
		{
			if ( ! Utils.Utils.IsAdministrator() )
			{
				// If not administrator, then hide delete and delete columns.
				e.Item.Cells[5].Visible = false;
				e.Item.Cells[6].Visible = false;
			}
		}

		/// <summary>
		/// This method is called when the page index is changed in the datagrid.
		/// </summary>
		/// <param name="o"></param>
		/// <param name="e"></param>
		protected void dgCourses_PageChanger(object o, DataGridPageChangedEventArgs e)
		{
			dgCourses.CurrentPageIndex = e.NewPageIndex;

			int id = int.Parse(Request.QueryString["Id"]);
			LoadCourses(id);
		}

		#endregion Courses

		#region Classmates
		
		/// <summary>
		/// Load all classmates for this college.
		/// </summary>
		/// <param name="collegeId"></param>
		private void LoadClassmates(int collegeId)
		{
			// Query to find the  courses offered in this college.
			string query = "Select Classmates.Id, Courses.Id as CourseId, CourseName, MajorSubject, Members.Name as MemberName, Classmates.userId, YearCompleted from Courses, Members, Classmates where Classmates.CollegeId = " + collegeId + " AND Classmates.userId = Members.userId AND Classmates.CourseId = Courses.Id";

			if ( txtName.Text != "" && txtName.Text != null )
			{
				query += " AND Members.Name like '%" + txtName.Text + "%' "; 
			}

			if ( ddlCourses.SelectedIndex > 0 )
			{
				query += " AND Courses.CourseName = '" + ddlCourses.SelectedValue + "' "; 
			}

			if ( ddlMajors.SelectedIndex > 0 )
			{
				query += " AND Courses.MajorSubject = '" + ddlMajors.SelectedValue + "' "; 
			}

			if ( ddlYears.SelectedIndex > 0 )
			{
				query += " AND Classmates.YearCompleted = '" + ddlYears.SelectedValue + "' "; 
			}

			DataTable data = Utils.DataManager.ExecuteQuery(query);

			if ( data.Rows.Count == 0 )
			{
				lblMessage1.Text = "No students listed.<BR>";
			}
			else
			{
				lblMessage1.Text = "";
			}

			dgClassmates.DataSource = data;
			dgClassmates.DataBind();
		}

		protected void btnSearchClassmates_Click(object sender, System.EventArgs e)
		{
			int collegeId = int.Parse(Request.QueryString["CollegeId"].ToString());

			LoadClassmates(collegeId);
		}
		
		/// <summary>
		/// This method is called from the data grid when the administrator clicks Edit or Delete link.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void dgClassmates_RowCommand(object sender, DataGridCommandEventArgs e)
		{
			string argument = e.CommandArgument.ToString();

			if (e.CommandName == "Delete")
			{
				// Delete the row.
				string query = "delete from Classmates Where Id = " + argument;

				Utils.DataManager.ExecuteNonQuery(query);

				LoadClassmates(int.Parse(Request.QueryString["CollegeId"].ToString()));
			}
			else if (e.CommandName == "Edit")
			{
				Response.Redirect("AddStudentToCollege.aspx?Id=" + argument + "&CollegeId=" + Request.QueryString["CollegeId"].ToString());
			}
		}

		/// <summary>
		/// This method is called from the Classmates datagrid.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void dgClassmates_DataBind(object sender, DataGridItemEventArgs e)
		{
			if ( ! Utils.Utils.IsAdministrator() )
			{
				// If not administrator, then hide edit and delete columns.
				e.Item.Cells[4].Visible = false;
				e.Item.Cells[5].Visible = false;
			}
		}

		/// <summary>
		/// This method is called when the page index is changed in the datagrid.
		/// </summary>
		/// <param name="o"></param>
		/// <param name="e"></param>
		protected void dgClassmates_PageChanger(object o, DataGridPageChangedEventArgs e)
		{
			dgCourses.CurrentPageIndex = e.NewPageIndex;

			int id = int.Parse(Request.QueryString["CollegeId"]);
			LoadClassmates(id);
		}

		/// <summary>
		/// This method loads the list of years
		/// </summary>
		private void LoadYearsDropdown()
		{
			ddlYears.Items.Add("ALL");

			// Populate the years starting from 1925 to (current year + 5)
			for (int year = (DateTime.Now.Year + 5); year > 1925; year--)
			{
				ddlYears.Items.Add(year.ToString());
			}

			ddlYears.SelectedIndex = 0;
		}

		/// <summary>
		/// This method loads the list of all courses for the selected college.
		/// </summary>
		private void LoadCoursesDropdown()
		{
			int collegeId = int.Parse(Request.QueryString["CollegeId"]);
			string query = "Select DISTINCT CourseName from Courses, CollegeCourses where Courses.Id = CollegeCourses.CourseId AND CollegeCourses.CollegeId = " + collegeId;
			DataTable table = Utils.DataManager.ExecuteQuery(query);
				
			ddlCourses.DataTextField = "CourseName";
			ddlCourses.DataValueField = "CourseName";
			ddlCourses.DataSource = table;
			ddlCourses.DataBind();

			ddlCourses.Items.Insert(0, "ALL");
		}

		#endregion Classmates

		#region College Photos
		
		/// <summary>
		/// Load all photos for this college.
		/// </summary>
		/// <param name="collegeId"></param>
		private void LoadPhotos(int collegeId)
		{
			// Query to find the  courses offered in this college.
			string query = "Select * from CollegePhotos where CollegeId = " + collegeId;

			DataTable data = Utils.DataManager.ExecuteQuery(query);

			if ( data.Rows.Count == 0 )
			{
				lblMessage1.Text = "No photos listed.<BR>";
			}
			else
			{
				lblPhotos.Text = "<table><tr>";
				int count = 0;
				foreach (DataRow row in data.Rows )
				{
					count = count + 1;
					lblPhotos.Text += "<td><a href='ViewPhoto.aspx?PhotoId=" + row["Id"].ToString() + "'><img src='../pictures/colleges/thumbs/" + row["PhotoPath"].ToString() + "' border=0></a> </td>";
					if ( count % 5 == 0 )
					{
						lblPhotos.Text += "</TR><TR>";
					}
				}
				lblPhotos.Text += "</TR></table>";
			}
		}

		/// <summary>
		/// This event is triggered when user press the SAVE button on photo upload panel.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void btnSave_Click(System.Object sender, System.EventArgs e)
		{		
			if ( !Utils.Utils.IsAdministrator() )
				return;

			string pageAction = Request.QueryString["PageAction"].ToString();

			if ( pageAction.ToLower() != "addphoto" )
			{
				lblMessage.Text = "Invalid Page Action";
				return;
			}

			string fileName = "";

			if ( File1.PostedFile == null || File1.PostedFile.FileName == "")
			{
				lblMessage.Text = "Please select an image file by clicking on the 'Browse' button.";
				lblMessage.ForeColor = Color.FromName("RED");
				return;
			}

			int collegeId = Int32.Parse(Request.QueryString["CollegeId"]);
			string title = Utils.Utils.MakeSafeWord(txtPhotoTitle.Text);

			bool primary = chkPrimary.Checked; // This flag indicates whether the photo is an important photo
			
			if ( File1.PostedFile != null && File1.PostedFile.FileName != "" )
			{
				// Make a filename
				fileName = Int32.Parse(Request.QueryString["CollegeId"]) + "__" + DateTime.Now.Day + DateTime.Now.Hour + DateTime.Now.Minute + "__" + System.IO.Path.GetFileName(File1.PostedFile.FileName);
			
				// let us save the image into a folder
				string savePath = Server.MapPath("../pictures/colleges/");

				// Let us create another folder for the thumbnail images.
				string thumbsPath = savePath + "/thumbs/";

				string saveFileFullName = System.IO.Path.Combine(savePath, fileName);
				string thumbFileFullName = System.IO.Path.Combine(thumbsPath, fileName);

				System.IO.Directory.CreateDirectory(savePath);
				System.IO.Directory.CreateDirectory(thumbsPath);

				File1.PostedFile.SaveAs(saveFileFullName);
				PictureUploadManager.CreateThumbNail(File1.PostedFile.InputStream, thumbFileFullName, 200);
			}

			// Save a record in the CollegePhotos table with the Photo file name. The actual photo is saved as a file in the hard disk.
            Utils.DataManager.ExecuteNonQuery("insert into CollegePhotos (CollegeId, PhotoPath, Title, [Primary], PostedUser) values (" + collegeId + ", '" + fileName + "', '" + title + "', " + (primary == true ? 1 : 0) + ", '" + Session["CurrentUser"].ToString() + "')");

			// Relead the photos so that the new photo also will appear.
			LoadPhotos(collegeId);
		}

		protected void btnCancel_Click(System.Object sender, System.EventArgs e)
		{
			pnlEditPhotos.Visible = false;
		}

		#endregion

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.lnkEdit.Click += new System.EventHandler(this.lnkEdit_Click);
            this.lnkDelete.Click += new System.EventHandler(this.lnkDelete_Click);
            this.btnSearchClassmates.Click += new System.EventHandler(this.btnSearchClassmates_Click);
            this.Load += new System.EventHandler(this.Page_Load);
		}
		#endregion

	}
}
