using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;


namespace IndiaStudyChannel.Courses
{
	/// <summary>
	/// Summary description for AddCourse.
	/// </summary>
	public partial class AddCourse : System.Web.UI.Page
	{
	
		protected void Page_Load(object sender, System.EventArgs e)
		{
            this.Page.Form.DefaultFocus = txtCourseName.ClientID;

			if ( Page.IsPostBack )
				return;

			// Make sure user has logged in before can post a university.

			if ( Session["CurrentUser"] == null )
			{
				// User has not logged in. Redirect to login page and pass current URL as a query string
				// so that after login, we can redirect user back to this page again.
				Response.Redirect("../Members/Login.aspx?ReturnUrl=" + Request.Url.PathAndQuery);
			}

			// Load the list of Course Categories in the drop down.
			LoadCourseCategories();

			string courseId = Request.QueryString["Id"];
			if ( courseId == null )
			{
				// No course id is passed in query string. So we are here to add a new course.
			}
			else
			{
				// Course Id is passed as query string. So we are here to edit a course.

				// Pre populate the course by the id.
				LoadCourseDetails( int.Parse(courseId) );
			}			
		}

		/// <summary>
		/// This method reads the details of the selected course and displays in the UI.
		/// </summary>
		/// <param name="courseId"></param>
		private void LoadCourseDetails( int courseId )
		{
			// Write the query to find the exact record from the database matching the given Id.
			string query = "Select Id, CourseName, MajorSubject, CourseCategoryId, Duration from Courses where Id = " + courseId;
			DataTable table = Utils.DataManager.ExecuteQuery(query);

			if ( table.Rows.Count > 0 )
			{
				DataRow dr = table.Rows[0];	// take the first row since we can assume that there will be only one row matching the id.
				// Only the administrator or the person who originally submitted this course can edit this. Make sure 
				// nobody else is trying to edit this.
				if ( !Utils.Utils.IsOwner(dr["PostedUser"]) )
				{
					lblMessage.Text = "Sorry, you are not the owner of this submission and you are not allowed to edit this. Please <a href='../Members/Login.aspx?ReturnUrl=" + Request.Url.PathAndQuery + "'>Sign In</a> using an Id with appropriate permissions.";
					btnSubmit.Enabled = false;
					return;
				}

				txtCourseName.Text = dr["CourseName"].ToString();
				txtSubjects.Text = dr["Subjects"].ToString();
				txtDuration.Text = dr["Duration"].ToString();

				// Initialize the drop down to the saved course.
				ddlCourseCategoryId.SelectedItem.Value = dr["CourseCategoryId"].ToString();
			}
		}
	
	
	#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    

		}
		#endregion

		protected void btnSubmit_Click(object sender, System.EventArgs e)
		{
			string coursename = txtCourseName.Text.Replace("'","''");
			string majorSubject = txtSubjects.Text.Replace("'","''");
			string duration = txtDuration.Text.Replace("'","''");
			string alternateNames = txtAlternateNames.Text.Replace("'","''");
			string currentUser = Session["CurrentUser"].ToString();

			string coursecategoryid = ddlCourseCategoryId.SelectedItem.Value;

			string courseId = Request.QueryString["Id"];

			string query;
			if ( courseId == null )
			{
				// There is no query string passed. We are adding a course.
				query = "insert into Courses (CourseName, CourseCategoryId, Duration, MajorSubject, AlternateNames, PostedUser) values('" + coursename + "', " + coursecategoryid + ", '" + duration + "', '" + majorSubject + "', '" + alternateNames + "', '" + currentUser + "')";
			}
			else
			{
				// collegeId is passed as query string... this means we are editing an existing course.
				query = "Update Courses set CourseName= '" + coursename + "', CourseCategoryId = '" + coursecategoryid + "', Duration = '" + duration + "', MajorSubject = '" + majorSubject + "', AlternateNames = '" + alternateNames + "' where Id = " + courseId;
			}
			
			Utils.DataManager.ExecuteNonQuery(query);

			Response.Redirect("Index.aspx");
		}

		/// <summary>
		/// This method populates the course category drop down.
		/// </summary>
		private void LoadCourseCategories()
		{
			string query = "Select Id, CategoryName from CourseCategories";
			DataTable table = Utils.DataManager.ExecuteQuery(query);
		
			ddlCourseCategoryId.DataTextField = "CategoryName";
			ddlCourseCategoryId.DataValueField = "Id";
			ddlCourseCategoryId.DataSource = table;            
			ddlCourseCategoryId.DataBind();
		}

		protected void btnCancel_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("Index.aspx");
		}
	}
}
