using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;


namespace IndiaStudyChannel.Courses
{
	/// <summary>
	/// Summary description for CourseDetails.
	/// </summary>
	public partial class CourseDetails : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label lblId;
		protected System.Web.UI.WebControls.Label lblDescription;
		protected System.Web.UI.WebControls.Label lblFeesStructure;
		protected System.Web.UI.WebControls.Label lblSeatCount;
	
		protected void Page_Load(object sender, System.EventArgs e)
		{
			int id = int.Parse(Request.QueryString["Id"].ToString());
			
			LoadCourseDetails(id);
			LoadColleges(id);
		}

		protected void lnkEdit_Click(object sender, System.EventArgs e)
		{
			int id = int.Parse(Request.QueryString["Id"].ToString());

            Response.Redirect("AddCourse.aspx?Id=" + id);
		}

		protected void lnkDelete_Click(object sender, System.EventArgs e)
		{
			if ( ! Utils.Utils.IsAdministrator() )
			{
				lblMessage.Text = "Sorry, only administrator has permission to delete this entry.";
				return;
			}

			int id = int.Parse(Request.QueryString["Id"].ToString());
			DeleteCourse(id);
		}

		/// <summary>
		/// Lod the details of the selected course.
		/// </summary>
		/// <param name="courseId"></param>
		private void LoadCourseDetails(int courseId)
		{
			// Query to find the details of the specified course.
			string query = "Select Courses.Id, Courses.COurseName, Posteduser, Courses.Duration, Courses.majorSubject, CourseCategories.CategoryName from Courses, CourseCategories where CourseCategories.Id = Courses.CourseCategoryId and Courses.Id ='" + courseId + "'";
			DataTable table = Utils.DataManager.ExecuteQuery(query);

			if ( table.Rows.Count > 0 )
			{
				DataRow dr = table.Rows[0];	// take the first row since we can assume that there will be only one row matching the id.

                this.Master.Page.Title = dr["CourseName"].ToString() + " " + dr["MajorSubject"].ToString() + " course and colleges";

				lblCourseName.Text = dr["CourseName"].ToString();
				lblCourseCategoryId.Text = dr["CategoryName"].ToString();
				lblDuration.Text = dr["Duration"].ToString();
				lblSubjects.Text = dr["MajorSubject"].ToString();

				// Only the administrator or the person who originally submitted this course can edit this. Make sure 
				// nobody else is trying to edit this.
				if ( Utils.Utils.IsOwner(dr["PostedUser"]) )
				{
					lnkEdit.Visible = true;
				}
				else
				{
					lnkEdit.Visible = false;
				}

				// Only administrator can delete a course.
				if ( Utils.Utils.IsAdministrator() )
				{
					lnkDelete.Visible = true;
				}
				else
				{
					lnkDelete.Visible = false;
				}
			}
		}

		/// <summary>
		/// Load all colleges which run this course. This information is stored in the table 'CollegeCourses'
		/// </summary>
		/// <param name="courseId"></param>
		private void LoadColleges(int courseId)
		{
			// Query to find the colleges which run the specified course.
			string query = "Select CollegeCourses.Id, Colleges.Id as CollegeId, CollegeName, Universities.UniversityName from Colleges, CollegeCourses, Universities where Universities.Id = Colleges.UniversityId AND CollegeCourses.CourseId = " + courseId + " AND CollegeCourses.CollegeId = Colleges.Id";
			DataTable table = Utils.DataManager.ExecuteQuery(query);

			if ( table.Rows.Count == 0 )
			{
				lblMessage1.Text = "No colleges found offering this course.";
			}
			else
			{			    
				dgResults.DataSource = table;
				dgResults.DataBind();
			}
		}

		private void DeleteCourse(int id )
		{
			// Before we delete a course, we must delete all college-course relation
			// Query to delete all college courses for this course
			string query = "delete from CollegeCourses Where CourseId = " + id;
			Utils.DataManager.ExecuteNonQuery(query);

			// Query to delete a specific course
			string query2 = "delete from Courses Where Id = " + id;
			Utils.DataManager.ExecuteNonQuery(query2);

			Response.Redirect ("Index.aspx");
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    

		}
		#endregion

	}
}
