using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;


namespace IndiaStudyChannel.Universities
{
	/// <summary>
	/// Summary description for AddUniversity.
	/// </summary>
	public partial class AddUniversity : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.DropDownList ddlUniversities;
	
		protected void Page_Load(object sender, System.EventArgs e)
		{
            this.Page.Form.DefaultFocus = txtUniversityName.ClientID;

			if ( Page.IsPostBack )
				return;

			// Make sure user has logged in before can post a university.

			if ( Session["CurrentUser"] == null )
			{
				// User has not logged in. Redirect to login page and pass current URL as a query string
				// so that after login, we can redirect user back to this page again.
				Response.Redirect("../Members/Login.aspx?ReturnUrl=" + Request.Url.PathAndQuery);
			}

            string universityId = Request.QueryString["UniversityId"];
			if ( universityId == null )
			{
				// No university id is passed in query string. So we are here to add a new university.
			}
			else
			{
				// University Id is passed as query string. Let us edit the existing university data.
				LoadUniversityDetails( int.Parse(universityId) );
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    

		}
		#endregion

		protected void btnSubmit_Click(object sender, System.EventArgs e)
		{
			if ( txtDescription.Text.Length > 1024 )
			{
				lblMessage.Text = "Description too long. Maximum length is 1024 characters.";
				return;
			}

			if ( txtAddress.Text.Length > 256 )
			{
				lblMessage.Text = "Address too long. Maximum length is 256 characters.";
				return;
			}

			// Must replace all single quotes with 2 single quotes to avoid failing the query since
			// single quote is an escape character in the database.

			string universityname = txtUniversityName.Text.Replace("'","''");
			string address = txtAddress.Text.Replace("'","''");
			string city = txtCity.Text.Replace("'","''");
			string state = txtState.Text.Replace("'","''");
			string phone1 = txtPhoneNumber1.Text.Replace("'","''");
			string phone2 = txtPhoneNumber2.Text.Replace("'","''");
			string email = txtEmail.Text.Replace("'","''");
			string homepage = txtHomePage.Text.Replace("'","''");
			string description = txtDescription.Text.Replace("'","''");
			string postedUser = Session["CurrentUser"].ToString();

            string universityId = Request.QueryString["UniversityId"];
			string query;
			if ( universityId == null )
			{
				// There is no query string passed. We are adding a university.
				query = "insert into Universities (UniversityName, Address, City, State, PhoneNumber1, PhoneNumber2, Email, HomePage, Description, PostedUser) values('" + universityname + "','" + address + "', '" + city + "', '" + state + "', '" + phone1 + "','" + phone2 + "','" + email + "','" + homepage + "', '" + description + "', '" + postedUser + "')";

				Utils.DataManager.ExecuteNonQuery(query);
			}
			else
			{
				// universityId is passed as query string... this means we are editing an existing university.
				query = "Update Universities set UniversityName= '" + universityname + "', Address = '" + address + "', City = '" + city + "', State = '" + state + "', PhoneNumber1 = '" + phone1 + "', PhoneNumber2 = '" + phone2 + "', Email = '" + email + "', HomePage = '" + homepage + "', Description = '" + description + "' where Id = " + int.Parse(universityId);

				Utils.DataManager.ExecuteNonQuery(query);

				Response.Redirect ("UniversityDetails.aspx?UniversityId=" + int.Parse(universityId));
			}
			

			Response.Redirect("Index.aspx");
		}

		/// <summary>
		/// This method pre populates the existing data of the current university.
		/// </summary>
		/// <param name="universityId"></param>
		private void LoadUniversityDetails( int universityId )
		{
			string query = "Select Id, UniversityName, City, State, Address, PhoneNumber1, PhoneNumber2, Email, HomePage, Description, PostedUser from Universities where Id = " + universityId;

			DataTable table = Utils.DataManager.ExecuteQuery(query);
			DataRow dr = table.Rows[0];

			// Only the administrator or the person who originally submitted this course can edit this. Make sure 
			// nobody else is trying to edit this.
			if ( !Utils.Utils.IsOwner(dr["PostedUser"]) )
			{
				lblMessage.Text = "Sorry, you are not the owner of this submission and you are not allowed to edit this. Please <a href='../Members/Login.aspx?ReturnUrl=" + Request.Url.PathAndQuery + "'>Sign In</a> using an Id with appropriate permissions.";
				btnSubmit.Enabled = false;
				return;
			}

			txtUniversityName.Text = dr["UniversityName"].ToString();
			txtAddress.Text = dr["Address"].ToString();
			txtCity.Text = dr["City"].ToString();
			txtState.Text = dr["State"].ToString();
			txtPhoneNumber1.Text = dr["PhoneNumber1"].ToString();
			txtPhoneNumber2.Text = dr["PhoneNumber2"].ToString();
			txtEmail.Text = dr["Email"].ToString();
			txtHomePage.Text = dr["HomePage"].ToString();
			txtDescription.Text = dr["Description"].ToString();
		}

		protected void btnCancel_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("Index.aspx");
		}
	}
}
