using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;


namespace IndiaStudyChannel.Universities
{
	/// <summary>
	/// Summary description for UniversityDetails.
	/// </summary>
	public partial class UniversityDetails : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label lblUniversity;
        protected string universityName = "";
	
		protected void Page_Load(object sender, System.EventArgs e)
		{	
			int id = int.Parse(Request.QueryString["UniversityId"].ToString());

			LoadColleges(id);
			ShowUniversityDetails(id);			
		}

		protected void lnkEdit_Click(object sender, System.EventArgs e)
		{
            int id = int.Parse(Request.QueryString["UniversityId"].ToString());

			Response.Redirect("AddUniversity.aspx?UniversityId=" + id);
		}

		protected void lnkDelete_Click(object sender, System.EventArgs e)
		{
			if ( ! Utils.Utils.IsAdministrator() )
			{
				lblMessage.Text = "Sorry, only administrator has permission to delete this entry.";
				return;
			}

			int id = int.Parse(Request.QueryString["UniversityId"].ToString());
			DeleteUniversity(id);
		}

		protected void dgResults_DataBind(object sender, DataGridItemEventArgs e)
		{
			if ( ! Utils.Utils.IsAdministrator() )
			{
				// If not administrator, then hide delete and delete columns.
				e.Item.Cells[5].Visible = false;
				e.Item.Cells[6].Visible = false;
			}
		}

		/// <summary>
		/// This method displays the details of the specific university
		/// </summary>
		/// <param name="universityId"></param>
		private void ShowUniversityDetails(int universityId)
		{
			// Query to retrieve university details.
			string query = "Select Universities.* from Universities where Universities.Id ='" + universityId + "'";
			DataTable table = Utils.DataManager.ExecuteQuery(query);
			DataRow dr = table.Rows[0];

			// Only the administrator or the person who originally submitted this university can edit this. Make sure 
			// nobody else is trying to edit this.
			if ( Utils.Utils.IsOwner(dr["PostedUser"]) )
			{
				lnkEdit.Visible = true;
			}
			else
			{
				lnkEdit.Visible = false;
			}

			// Only administrator can delete a university.
			if ( Utils.Utils.IsAdministrator() )
			{
				lnkDelete.Visible = true;
			}
			else
			{
				lnkDelete.Visible = false;
			}

            // This is used to display the title in the aspx page.
            universityName = dr["UniversityName"].ToString();

            // Ensure the word 'university' is there in the title so that search engines will capture it properly!
            if (universityName.ToLower().IndexOf("university") == -1)
                universityName = universityName + " University";

			lblName2.Text = dr["UniversityName"].ToString();
			lblAddress.Text = dr["Address"].ToString();
			lblCity.Text = dr["City"].ToString();
			lblState.Text = dr["State"].ToString();
			lblPhoneNumber1.Text = dr["PhoneNumber1"].ToString();
			lblPhoneNumber2.Text = dr["PhoneNumber2"].ToString();
			lblEmail.Text = dr["Email"].ToString();
			lblHomePage.Text = dr["HomePage"].ToString();
			lblDescription.Text = dr["Description"].ToString();

            this.Master.Page.Title = universityName + " telephone number & email address";
		}

		/// <summary>
		/// Load all courses running in this university.
		/// </summary>
		/// <param name="universityId"></param>
		private void LoadColleges(int universityId)
		{
			// Query to find the colleges based on the filter criteria
			string query = "Select TOP 1000 Colleges.Id, CollegeName, Colleges.City, Colleges.State, Colleges.PhoneNumber1, Colleges.HomePage, UniversityId, Universities.UniversityName from ";
			query += " Colleges, Universities WHERE Colleges.UniversityId = Universities.Id";
			query += " AND Universities.Id = " + universityId;

			DataTable table = Utils.DataManager.ExecuteQuery(query);
			dgResults.DataSource = table;
			dgResults.DataBind();
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    

		}
		#endregion

		// This method is to delete a university based on it's Id.
		private void DeleteUniversity(int id )
		{
			// Before we delete a university, we must delete all courses offered in this university.
			// Query to delete all university courses for this university
			string query = "Update Colleges set UniversityId = 1 Where UniversityId = " + id;
			Utils.DataManager.ExecuteNonQuery(query);

			// Query to delete a specific university.
			string query2 = "delete from Universities Where Id = " + id;
			Utils.DataManager.ExecuteNonQuery(query2);

			Response.Redirect("Index.aspx");
		}	
	}
}
