using System;

namespace IndiaStudyChannel.Utils
{
	/// <summary>
	/// Summary description for Utils.
	/// </summary>
	public class Utils
	{
		public Utils()
		{
		}

		/// <summary>
		/// This method removes some dangerous characters from the word to avoid 'Sql Injection attack'.
		/// </summary>
		/// <param name="s"></param>
		/// <returns></returns>
		public static string MakeSafeWord(string s)
		{
			if ( s == null )
				return "";

			return s.Replace("'", "").Replace("--", "");
		}

		/// <summary>
		/// This method checks if the passed user id is an adinistrator or if this is same as current user.
		/// </summary>
		/// <param name="userId"></param>
		/// <returns></returns>
		public static bool IsOwner(object userId)
		{
			if ( System.Web.HttpContext.Current.Session["CurrentUser"] == null )
			{
				// There is no userid saved in session. This means user has not logged in.
				return false;
			}

			// Get current user from session.
			string currentUser = System.Web.HttpContext.Current.Session["CurrentUser"].ToString();

			// Get the admin user id from config file.
			string adminUser = System.Configuration.ConfigurationSettings.AppSettings["AdminUser"];

			if ( currentUser == adminUser )
			{
				// Current user is an administrator. Administrator is Owner for all submissions.
				return true;
			}

			if ( userId != null && userId.ToString() == currentUser )
			{
				// Current user is same as the userId passed.
				return true;
			}

			return false;
		}

	
		/// <summary>
		/// This method checks if the passed user id is an adinistrator or if this is same as current user.
		/// </summary>
		/// <param name="userId"></param>
		/// <returns></returns>
		public static bool IsAdministrator()
		{
			if ( System.Web.HttpContext.Current.Session["CurrentUser"] == null )
			{
				// There is no userid saved in session. This means user has not logged in.
				return false;
			}

			// Get current user from session.
			string currentUser = System.Web.HttpContext.Current.Session["CurrentUser"].ToString();

			// Get the admin user id from config file.
			string adminUser = System.Configuration.ConfigurationSettings.AppSettings["AdminUser"];

			if ( currentUser == adminUser )
			{
				// Current user is an administrator. Administrator is Owner for all submissions.
				return true;
			}

			return false;
		}

        public static string FormatFileName(string s)
        {
            char[] chars = {'#', '@', '?', ':', '\'', '\"', '.', '/', '\\', ' ', '<', '>', '&', '*', '(', ')', '!', ',', ';', ':', '-', '+', '='};
            foreach (char c in chars)
            {
                s = s.Replace(c, '-');
            }
            
            s = s.Replace(" ", "-");
            s = s.Replace("--", "-");

            if ( s.LastIndexOf("-") == (s.Length - 1) && s.Length > 2 )
            {
                s = s.Substring(0, s.Length - 1);
            }

            return s;
        }
	}
}
